@@ -1,13 +1,19 @@
-from ..vtask import VTask
+from ..vtask import VTask, TryLater
 import time
-from ..sparts import option
+from ..sparts import option, counter, samples, SampleType
 from threading import Event
 
 
 class PeriodicTask(VTask):
     INTERVAL = None
 
-    interval = option('interval', type=float, metavar='SECONDS',
+    execute_duration_ms = samples(windows=[60, 240],
+       types=[SampleType.AVG, SampleType.MAX, SampleType.MIN])
+    n_iterations = counter()
+    n_slow_iterations = counter()
+    n_try_later = counter()
+
+    interval = option(type=float, metavar='SECONDS',
                       default=lambda cls: cls.INTERVAL,
                       help='How often this task should run [%(default)s] (s)')
 
@@ -21,13 +27,24 @@ class PeriodicTask(VTask):
         super(PeriodicTask, self).stop()
 
     def _runloop(self):
+        t0 = time.time()
         while not self.service._stop:
-            t0 = time.time()
-            self.execute()
-            to_sleep = time.time() - (t0 + self.interval)
+            try:
+                self.execute()
+            except TryLater:
+                self.n_try_later.increment()
+                continue
+
+            self.n_iterations.increment()
+            self.execute_duration_ms.add((time.time() - t0) * 1000)
+            to_sleep = (t0 + self.interval) - time.time()
             if to_sleep > 0:
                 if self.stop_event.wait(to_sleep):
                     return
+            else:
+                self.n_slow_iterations.increment()
+
+            t0 = time.time()
 
     def execute(self, context=None):
         self.logger.debug('execute')
