@@ -1,10 +1,14 @@
 import logging
 import threading
+from .sparts import _SpartsObject
 
 
-class VTask(object):
+_REGISTERED_TASKS = set()
+
+class VTask(_SpartsObject):
     OPT_PREFIX = None
     LOOPLESS = False
+    DEPS = []
     workers = 1
 
     @property
@@ -40,9 +44,27 @@ class VTask(object):
                 while thread.isAlive():
                     thread.join(0.5)
 
+    @property
+    def running(self):
+        for thread in self.threads:
+            if thread.isAlive():
+                return True
+        return False
+
     def _run(self):
         try:
             self._runloop()
+        except Exception:
+            # In general, you should not get here.  So, we will shutdown the
+            # server.  It is better for your service to *completely* crash in
+            # response to an unhandled error, than to continue on in some sort
+            # of half-alive zombie state.  Please catch your exceptions.
+            # Consider throwing a TryLater if this task is a subclass of 
+            # QueueTask or PeriodicTask.
+            #
+            # I hate zombies.
+            self.logger.exception("Unhandled exception in %s", self.name)
+            self.service.shutdown()
         finally:
             self.logger.debug('Thread %s exited',
                               threading.currentThread().name)
@@ -73,6 +95,14 @@ class VTask(object):
             if regfunc is not None:
                 regfunc(cls, ap)
 
+    @classmethod
+    def register(cls):
+        _REGISTERED_TASKS.add(cls)
+
+
+def get_registered_tasks():
+    return _REGISTERED_TASKS.copy()
+
 
 class SkipTask(Exception):
     pass
@@ -87,3 +117,16 @@ class ExecuteContext(object):
         self.attempt = attempt
         self.item = item
         self.deferred = deferred
+
+
+def resolve_dependencies(task_classes):
+    result = []
+    for t in task_classes:
+        assert issubclass(t, VTask)
+        for dep in resolve_dependencies(t.DEPS):
+            if dep not in result:
+                result.append(dep)
+
+        if t not in result:
+            result.append(t)
+    return result
